@@ -1,3 +1,19 @@
+#' @title Height of math teachers
+#' @description Height of a sample of math teachers in Danish high
+#'     schools collected at a continued education day at Mariager Fjord Gymnasium in 2019.
+#'
+#' Format:
+#' height: Height in centimeters
+#' sex: male or female
+#'
+#' @examples
+#'
+#' aggregate(height ~  sex, data=math_teachers, FUN=mean)
+#' aggregate(height ~  sex, data=math_teachers, FUN=function(x) {c(mean=mean(x), sd=sd(x))})
+#' 
+"math_teachers"
+
+
 ##' @title Berkeley Growth Study data
 ##' @description dataframe with heights of 39 boys and 54 girls from
 ##'     age 1 to 18 and the ages at which they were collected.
@@ -145,9 +161,9 @@
 #'  correct species. Walker (1962) wanted to know whether the chirps
 #'  of the crickets Oecanthus exclamationis (abbreviated exis) and
 #'  Oecanthus niveus (abbreviated nius) had different pulse rates. See
-#'  \url{https://www.biostathandbook.com/} for details.  (The
+#'  the biostathandbook for details. (The
 #'  abbreviations are made from the the first two and last two letters
-#'  of the species.) He measured the pulse rate of the crickets
+#'  of the species.) Walker measured the pulse rate of the crickets
 #'  (variable `pps`) at a variety of temperatures (`temp`):
 #'
 #' @examples
